changeset 31847:ea4bb5fe1fdc

Document the default explicitly
author Paul Aurich <paul@darkrain42.org>
date Thu, 05 May 2011 03:40:29 +0000
parents a88631af0f5e
children 0d4702446530
files libpurple/notify.h
diffstat 1 files changed, 3 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/libpurple/notify.h	Tue May 03 21:22:51 2011 +0000
+++ b/libpurple/notify.h	Thu May 05 03:40:29 2011 +0000
@@ -112,7 +112,7 @@
 typedef struct
 {
 	char *title;           /**< Title of the column. */
-	gboolean visible;
+	gboolean visible;      /**< Should the column be visible to the user. Defaults to TRUE. */
 
 } PurpleNotifySearchColumn;
 
@@ -267,7 +267,8 @@
 PurpleNotifySearchResults *purple_notify_searchresults_new(void);
 
 /**
  * Returns a newly created search result column object.
  *
  * @param title Title of the column. NOTE: Title will get g_strdup()ed.
  *
@@ -267,7 +267,8 @@
 
 /**
- * Returns a newly created search result column object.
+ * Returns a newly created search result column object.  The column defaults
+ * to being visible.
  *
  * @param title Title of the column. NOTE: Title will get g_strdup()ed.